/*
 * Internal declarations for libcdecl.
 * Copyright © 2021 Nick Bowler
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
#ifndef CDECL_INTERNAL_H_
#define CDECL_INTERNAL_H_

#include <stddef.h>
#include <gettext.h>

#define _(s) dgettext(PACKAGE, s)
#define N_(s) s

struct cdecl_error;
struct cdecl_declspec;

#if ENABLE_NLS
void cdecl__init_i18n(void);
#else
static inline void cdecl__init_i18n(void)
{
}
#endif

const char *cdecl__strerror(unsigned code);
void cdecl__err(unsigned code, ...);

unsigned long cdecl__build_typemap(struct cdecl_declspec *s);
struct cdecl_declspec *cdecl__normalize_specs(struct cdecl_declspec *specs);

size_t cdecl__advance_(char **buf, size_t *n, size_t amount);
size_t cdecl__advance(char **buf, size_t *n, size_t amount);
size_t cdecl__explain_specs(char *buf, size_t n, struct cdecl_declspec *s,
                                                 unsigned mask);
size_t cdecl__explain_pre_specs(char *buf, size_t n, struct cdecl_declspec *s);
size_t cdecl__explain_post_specs(char *buf, size_t n, struct cdecl_declspec *s);

#endif
